% Example_3_3.m Resistive Circuit
% This program solves for the internal node voltages for
% the circuit shown in Figure 3.1.
% The conductances G are in units of siemens
% The node voltage V are in units of volts
% The currents I are in units of amps
clear; clc;
g1 = 1/2200;
g2 = 1/10000;
g3 = 1/6900;
g4 = 1/9100;
g5 = 1/3300;
V1 = 12;
V2 = 3.3;
I1 = .002;
% Put the problem into standard form AX=C:
A = [ g1+g2+g3 -g2 -g3; -g2 g2+g4 -g4; -g3 -g4 g3+g4+g5];
C = [ V1*g1; I1; V2*g5 ];
X = A \ C ;
% print the results
fprintf('V1=%9.1f V\nV2=%9.1f V\nI1=%9.1e A\n',V1,V2,I1);
fprintf('g1=%9.5f S\ng2=%9.5f S\ng3=%9.5f S\n',g1,g2,g3);
fprintf('g4=%9.5f S\ng5=%9.5f S\n',g4,g5);
fprintf('\n');
fprintf('  Node #     v (volts)  \n');
fprintf('-------------------------\n');
for n=1:length(C)
    fprintf('  %3i     %9.1f\n', n,X(n));
end
