% Example_3_7.m: Eigenvalues and eigenvectors.
% L = eig(A) is a vector containing the eigenvalues of a 
% square matrix A.
% [M,D] = eig(A) produces a diagonal matrix D of
% eigenvalues and a full matrix M whose columns are the
% corresponding eigenvectors such that A*L = M*D.
% Units are in SI units.
clear; clc;
L1=15e-3; L2=25e-3; % henries
C1=1e-6; C2=33e-6;  % farads
A(1,1)=1/(L1*C1);
A(1,2)=-1/(L1*C1);
A(2,1)=-1/(L1*C2);
A(2,2)=1/(L1*C2) + 1/(L2*C2);
% Solve for eigenvalues and eigenvectors using derivation
% in Eqn 3.25: 
% lambda^2-(A(1,1)+A(2,2))
%      *lambda+(A(1,1)*A(2,2)-A(1,2)*A(2,1))=0
% Solve for lambda using quadratic formula:
b=-(A(1,1)+A(2,2)); c=A(1,1)*A(2,2)-A(1,2)*A(2,1);
lambda1=(-b+sqrt(b^2-4*c))/2;
lambda2=(-b-sqrt(b^2-4*c))/2;
% From Eqns 3.26 and 3.27:
eigenvector1=[1;-(A(1,1)-lambda1)/A(1,2)];
eigenvector2=[1;-(A(1,1)-lambda2)/A(1,2)];
fprintf('Eigenvalues solved via Equation 3.25: ');
fprintf('lambda1=%.0f  lambda2=%.0f\n',lambda1,lambda2);
fprintf('Eigenvectors solved via Equation 3.26 ');
fprintf('and 3.27:\n');
eigenvector1
eigenvector2
% Solve for eigenvalues and eigenvectors using MATLAB's
% eig function. Calling eig and returning result to a
% scalar will give the eigenvalues.
L=eig(A);
fprintf('Eigenvalues via MATLAB eig function: ');
fprintf('L(1)=%.0f  L(2)=%.0f\n',L(1),L(2));
% Calling eig and returning result to two variables will
% give the eigenvectors and a diagonal matrix of the
% eigenvalues.
[V D] = eig(A);
fprintf('Eigenvectors via MATLAB eig function:\n');
V1=V(:,1)
V2=V(:,2)
D
