% Example_6_3.m
% This program solves a system of 2 first order ordinary
% differential equations by the Runge-Kutta Method.
% First, define two functions to compute dr/dt and dy/dt:
rprime_func = @(t,r,y) 2.0*r*exp(-0.1*t) - 2.0*r*y;
yprime_func = @(r,y) -y + r*y;
% Open a file to write results:
fo=fopen('Example_6_3_output.txt','w');
fprintf(fo,'  t        r          y   \n');
fprintf(fo,'--------------------------\n');
% Define time interval and step size
tmax=10; steps=1000; h=tmax/steps;
% Initial conditions:
r(1)=1.0; y(1)=3.0; t(1)=0.0;
% Estimate of derivatives and marching in time.
for i=1:steps
    t(i+1)=i*h;
    K(1)=rprime_func(t(i),r(i),y(i));
    L(1)=yprime_func(r(i),y(i));
    K(2)=rprime_func(t(i)+h/2,r(i)+h/2*K(1),...
        y(i)+h/2*L(1));
    L(2)=yprime_func(r(i)+h/2*K(1),y(i)+h/2*L(1));
    K(3)=rprime_func(t(i)+h/2,r(i)+h/2*K(2),...
        y(i)+h/2*L(2));
    L(3)=yprime_func(r(i)+h/2*K(2),y(i)+h/2*L(2));
    K(4)=rprime_func(t(i)+h,r(i)+h*K(3),y(i)+h*L(3));
    L(4)=yprime_func(r(i)+h*K(3),y(i)+h*L(3));
    r(i+1)=r(i)+h/6*(K(1)+2*K(2)+2*K(3)+K(4));
    y(i+1)=y(i)+h/6*(L(1)+2*L(2)+2*L(3)+L(4));
    if mod(i-1,10)==0
       fprintf(fo,'%.2f %10.4f %10.4f\n',t(i),r(i),y(i));
    end
end
fclose(fo);
plot(t,r,t,y,'--'), xlabel('t'), ylabel('r,y');
grid, legend('r','y');
title('Runge-Kutta Solution For 2nd-Order System');
