% Example_6_8.m
% Find the electric potential between a parallel plate
% capacitor with fixed charge density between the plates
% and known boundary conditions.
clc; clear;
N=40;                 % step count
D=.0004;              % plate separation (meters)
h=D/N;                % step size
rho_o=1e4;            % coulomb/m^3
epsilon = 1.04e-12;   % dielectric between the plates
Vo=5;                 % voltage across plates
% First, calculate all values of x.  Also calculate
% the exact solution.
x = 0:h:D;
% Calculate exact solution (Equation 6.54)
phi_exact = (-rho_o/epsilon)* (x.^4/12 - (D/3)*x.^3 ...
    + (D^2/2)*x.^2 - ((epsilon*Vo/(D*rho_o))+(D^3/4))*x);
% Next, solve numerically using a tri-diagonal matrix.
% Define 'a', 'b', and 'c' vectors:
a = .5 * ones(1,N+1);
b = .5 * ones(1,N+1);
c = (rho_o*h^2/(2*epsilon))*( x.^2 - 2*D*x +D^2);
% Set boundary conditions for 'a', 'b', and 'c' vectors
a(1)=0; b(1)=0; c(1)=0;
a(N+1)=0; b(N+1)=0; c(N+1)=Vo;
% Solve tri-diagonal matrix by calculating "d" and 
% "e" vectors
d(1)=c(1);
e(1)=a(1);
for i=2:N+1
    d(i) = (c(i) + b(i)*d(i-1)) / (1 - b(i)*e(i-1));
    e(i) = a(i) / (1 - b(i)*e(i-1));
end
% calculate phi based on d and e, also calculate
% global error
phi(N+1)=d(N+1);
for i=N:-1:1
    phi(i) = d(i) + e(i)*phi(i+1);
end
% Plot numerical and exact solutions for phi:
plot(x,phi,'x',x,phi_exact);
xlabel('{\it x} (meters)'), ylabel('\Phi (volts)');
grid;
legend('numerical solution','exact solution',...
    'Location','SouthEast');
% Find worst-case global error:
error = abs( (phi - phi_exact) ./ phi_exact );
fprintf('Max global error for %d steps: %5.3f%%\n',...
    N,100*max(error));
