% Example_7_5.m: This program solves Equation 7.33 by
% converting it into a system of two differential
% equations and solving with ode45.
% Let v=y', Y=[y v], and Y'=[y' v'].
% Y(1)=y, Y(2)=v, Y'(1)=Y(2).
% Y'(2)=5*t-3Y(2)-2Y(1)  for t < 2
% Y'(2)=-3Y(2)-2Y(1)     for t >= 2
% Initial conditions: y(0)=1, y'(0)=0
clear; clc;
% Define initial conditions:
Y0=[1.0 0.0];
% Define time interval to solve:
dt=0.1; Tstop=4; Tspan=0:dt:Tstop;
% Solve the ODE directly with ode45:
[t,Yode45]=ode45('dydt2',Tspan,Y0);
% Compute the solution found via Laplace Transforms
% (Equation 7.35)
for i=1:length(Tspan)
    if Tspan(i) < 2
        Ylaplace(i)=2.5*Tspan(i)- 15/4 - ...
            9/4*exp(-2*Tspan(i))+7*exp(-Tspan(i));
    else
        Ylaplace(i)= -(9/4+15/4*exp(4)) ...
            * exp(-2*Tspan(i)) ...
            +(7+5*exp(2))*exp(-Tspan(i));
    end
end
plot(t,Yode45(:,1),'x',Tspan,Ylaplace),
title('ODE solutions using ode45 and Laplace Transform');
legend('ode45','Laplace');
