% Example_9_1.m
% This program determines the best fit polynomial curve
% passing through a given set of data points for
% polynomial degrees 2 thru 5.
clear; clc;
% Provided data set
X = [ -10   -8  -6 -4  -2  0 2   4   6  8  10 ];
Y = [-980 -620 -70 80 100 90 0 -80 -90 10 220 ];
% Fit to polynomials of degree m:
m=2:5;
% Create a second set of x points over the same interval
% in order to plot our fitted curve
X2 = -10:0.5:10;
% Vector to keep track of MSE (to print at end)
MSE=zeros(length(m));
for i=1:length(m)
    fprintf('m = %i \n',m(i));
    % an mth-degree polynomial has m+1 coefficients:
    A = zeros(m(i)+1);
    % do the fit
    A = polyfit(X,Y,m(i));
    % compute the MSE
    Yc = polyval(A,X);
    MSE(i) = (1/length(X)) * sum((Y-Yc).^2);
    % print table
    fprintf('    x        y         yc \n');
    fprintf('-----------------------------\n');
    for j=1:length(X)
        fprintf('%5.0f    %5.0f     %8.2f \n', ...
            X(j),Y(j),Yc(j));
    end
    fprintf('\n\n');
    % plot
    subplot(2,2,i);
    plot(X2,polyval(A,X2),X,Y,'o');
    xlabel('x'); ylabel('y'); grid;
    axis([ -10 10 -1500 500]);
    title(sprintf('Degree %d polynomial fit',m(i)));
end
% print computed MSE
fprintf('  m           MSE \n')
fprintf('----------------------\n');
for i=1:length(m)
    fprintf('  %g      %10.2f  \n',m(i),MSE(i))
end
